@@ -201,12 +201,12 @@ role {
 		my $self   = shift;
 		my $status = shift;
 
-		$self->_register_status( $status );
+		$self->_base_register_status( $status );
 	};
 
 	sub _base_register_status {
 		my $self   = shift;
-		my $status = shift // 0;
+		my $status = shift;
 		my $stath  = $self->stats;
 		$stath->{exit_status} = $status;
 		if ($status =~ /\D/) {
@@ -225,9 +225,10 @@ role {
 
 	around '_register_status' => sub {
 		my $orig = shift;
-		$orig->(@_);
 		my $self   = shift;
-		$self->_base_register_status( @_ );
+		my $status = shift || 0;
+		$orig->($self,$status);
+		$self->_base_register_status( $status );
 	};
 
 };
